
![nflogic banner](./resources/gh_banner-nflogic.png)

[![documentation](https://img.shields.io/badge/documentação-274A63?style=for-the-badge)](https://vflins.github.io/nflogic/nflogic.html)

Este software permite processar os dados de muitos arquivos de notas fiscais eletrônicas
e transformá-los em um conjunto de dados prontos para ser analisado por um analista de
dados ou incorporado em uma aplicação para empresas. Para mais informações sobre este
projeto, veja a documentação.

<hr>

[![build status](https://img.shields.io/github/actions/workflow/status/VFLins/nflogic/tests.yml?branch=main&label=testes&style=for-the-badge)](https://github.com/VFLins/nflogic/tree/main/tests)
[![test coverage](https://img.shields.io/endpoint?url=https%3A%2F%2Fraw.githubusercontent.com%2FVFLins%2Fnflogic%2Frefs%2Fheads%2Fmain%2F.github%2Fcoverage.json&style=for-the-badge)](https://github.com/VFLins/nflogic/tree/main/tests)
[![code style: black](https://img.shields.io/badge/estilo%20de%20código-black-black?style=for-the-badge)](https://black.readthedocs.io/)
